==> mule-devkit-plugin-studio-3.6.1-sources.jar: org/mule/devkit/generation/studio/editor/PatternTypeBuilder.java <==
/**
 * Mule Development Kit
 * Copyright 2010-2012 (c) MuleSoft, Inc.  All rights reserved.  http://www.mulesoft.com
 *
 * This software is protected under international copyright law. All use of this software is
 * subject to MuleSoft's Master Subscription Agreement (or other master license agreement)
 * separately entered into in writing between you and MuleSoft. If such an agreement is not
 * in place, you may not use the software.
 */


package org.mule.devkit.generation.studio.editor;

import org.mule.api.annotations.Category;
import org.mule.api.annotations.Paged;
import org.mule.api.annotations.Processor;
import org.mule.api.annotations.Transformer;
import org.mule.devkit.generation.api.Context;
import org.mule.devkit.model.Method;
import org.mule.devkit.model.module.Module;
import org.mule.devkit.model.module.connectivity.ConnectionManagementCapability;
import org.mule.devkit.model.module.connectivity.ManagedConnectionModule;
import org.mule.devkit.model.studio.AttributeCategory;
import org.mule.devkit.model.studio.AttributeType;
import org.mule.devkit.model.studio.Group;
import org.mule.devkit.model.studio.PatternType;
import org.mule.util.StringUtils;

import java.util.Collection;
import java.util.List;
import java.util.Map;

public class PatternTypeBuilder extends BaseStudioXmlBuilder {

    public PatternTypeBuilder(Context context, Method method, Module module) {
        super(context, method, module);
    }

    public PatternType build() {
        PatternType patternType = createPatternType();
        if (method.getAnnotation(Processor.class) != null) {
            Collection<AttributeCategory> attributeCategories = processMethodParameters();
            patternType.getAttributeCategoryOrRequiredSetAlternativesOrFixedAttribute().addAll(attributeCategories);
        }
        return patternType;
    }

    protected PatternType createPatternType() {
        PatternType patternType = new PatternType();
        patternType.setLocalId(helper.getLocalId(method));
        patternType.setCaption(helper.getFormattedCaption(method));
        patternType.setAbstract(true);
        if (method.getAnnotation(Processor.class) != null) {
            patternType.setExtends(helper.getUrl(module) + helper.getGlobalRefId(module.getModuleName()));
            String returnType = method.getReturnType().toString();

            if (method.getAnnotation(Paged.class) != null) {
                returnType = helper.getPagedReturnType(method);
            }

            patternType.setReturnType(returnType);
        } else if (method.getAnnotation(Transformer.class) != null) {
            patternType.setExtends(helper.getUrl(module) + AbstractTransformerBuilder.ABSTRACT_TRANSFORMER_LOCAL_ID);
            patternType.setDescription(helper.formatDescription(method.getJavaDocSummary()));
        }

        Category category = module.getAnnotation(Category.class);
        if (category != null && StringUtils.isNotBlank(category.name())) {
            patternType.setCategory(category.name());
        }

        patternType.setIcon(getIcon());
        patternType.setImage(getImage());
        return patternType;
    }

    protected String getImage() {
        if (method.getAnnotation(Transformer.class) != null) {
            return helper.getTransformerImage(module);
        } else {
            return helper.getConnectorImage(module);
        }
    }

    protected String getIcon() {
        if (method.getAnnotation(Transformer.class) != null) {
            return helper.getTransformerIcon(module);
        } else {
            return helper.getConnectorIcon(module);
        }
    }

    /**
     * Used when describing a processor, if the current module has connection management or if it has an strategy
     * with @ConnectionManagement that also has been annotated with @OverrideAtProcessors, then the processor must have
     * the parameters of @Connect as attributes as well.
     *
     * @param groupsByName
     * @param attributeCategoriesByName
     */
    @Override
    protected void processConnectionAttributes(Map<String, Group> groupsByName, Map<String, AttributeCategory> attributeCategoriesByName) {
        ConnectionManagementCapability connectionManagementCapability = null;
        if (module.manager().connectionManagementOverride().isPresent()){
            connectionManagementCapability = module.manager().connectionManagementOverride().get();
        } else if(module instanceof ManagedConnectionModule) {
            connectionManagementCapability = (ConnectionManagementCapability) module;
        }

        if (connectionManagementCapability != null ) {
            Group connectionAttributesGroup = new Group();
            connectionAttributesGroup.setCaption(helper.formatCaption(ADVANCED_CONNECTION_GROUP_NAME));
            connectionAttributesGroup.setId(StringUtils.uncapitalize(ADVANCED_CONNECTION_GROUP_NAME));

            groupsByName.put(ADVANCED_CONNECTION_GROUP_NAME, connectionAttributesGroup);

            List<AttributeType> connectionAttributes = getConnectionAttributes(connectionManagementCapability);
            connectionAttributesGroup.getRegexpOrEncodingOrModeSwitch().addAll(helper.createJAXBElements(connectionAttributes));

            AttributeCategory connectionAttributeCategory = new AttributeCategory();
            connectionAttributeCategory.setCaption(helper.formatCaption(MuleStudioEditorXmlGenerator.ADVANCED_ATTRIBUTE_CATEGORY_CAPTION));
            connectionAttributeCategory.setDescription(helper.formatDescription(MuleStudioEditorXmlGenerator.ADVANCED_ATTRIBUTE_CATEGORY_CAPTION));
            attributeCategoriesByName.put(MuleStudioEditorXmlGenerator.ADVANCED_ATTRIBUTE_CATEGORY_CAPTION, connectionAttributeCategory);
            connectionAttributeCategory.getGroup().add(connectionAttributesGroup);
        }
    }
}

==> mule-devkit-plugin-studio-3.9.14-sources.jar: org/mule/devkit/generation/studio/editor/PatternTypeBuilder.java <==
/**
 * (c) 2003-2015 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */

package org.mule.devkit.generation.studio.editor;

import org.mule.api.annotations.Category;
import org.mule.api.annotations.Paged;
import org.mule.api.annotations.Processor;
import org.mule.api.annotations.Transformer;
import org.mule.devkit.generation.api.Context;
import org.mule.devkit.model.Method;
import org.mule.devkit.model.module.Module;
import org.mule.devkit.model.module.ProcessorMethod;
import org.mule.devkit.model.module.connectivity.ConnectionManagementCapability;
import org.mule.devkit.model.module.connectivity.ManagedConnectionModule;
import org.mule.devkit.model.studio.AttributeCategory;
import org.mule.devkit.model.studio.AttributeType;
import org.mule.devkit.model.studio.ContainerType;
import org.mule.devkit.model.studio.Group;
import org.mule.devkit.model.studio.PatternType;
import org.mule.util.StringUtils;

import java.util.Collection;
import java.util.List;
import java.util.Map;

public class PatternTypeBuilder extends BaseStudioXmlBuilder {

    public PatternTypeBuilder(Context context, Method method, Module module) {
        super(context, method, module);
    }

    public PatternType build() {

        PatternType patternType = createPatternType();
        fillCommonPatternType(patternType);
        if (method.getAnnotation(Processor.class) != null) {
            Collection<AttributeCategory> attributeCategories = processMethodParameters();
            patternType.getAttributeCategoryOrRequiredSetAlternativesOrFixedAttribute().addAll(attributeCategories);
        }
        return patternType;
    }

    private PatternType createPatternType()
    {
        PatternType patternType;
        if (isContainer(method)){
            patternType = getContainerType();
        }else if (isContainerList(method)){
            patternType = getContainerListType();
        }else {
            patternType = getCommonPatternType();
        }
        return patternType;
    }

    private boolean isContainer(Method method){
        return (method instanceof ProcessorMethod) && ((ProcessorMethod) method).isContainer();
    }
    private boolean isContainerList(Method method){
        return (method instanceof ProcessorMethod) && ((ProcessorMethod) method).isContainerList();
    }
    /**
     * @return a container when a Processor is being parametrized with a NestedProcessor
     */
    private ContainerType getContainerType()
    {
        ContainerType containerType = new ContainerType();

        containerType.setPathExpression("${index}");
        containerType.setAcceptedByElements("!http://www.mulesoft.org/schema/mule/core/mule");
        containerType.setTitleColor("168, 206, 226"); //light blue with RBG
        containerType.getGraphicalContainer().setLocalId(helper.getLocalId(method) + "-nested");
        containerType.getGraphicalContainer().setAcceptsElements("!category:org.mule.tooling.ui.modules.core.exceptions");
        containerType.getGraphicalContainer().setShowsResponse(false);

        //putting the abstract attribute to false to make it visible in the palette
        containerType.setAbstract(false);
        return containerType;
    }

    private PatternType getContainerListType()
    {
        PatternType patternType= new PatternType();
        patternType.setCausesSplit(true);

        //putting the abstract attribute to false to make it visible in the palette
        patternType.setAbstract(false);
        return patternType;
    }

    private PatternType getCommonPatternType()
    {
        PatternType patternType = new PatternType();
        patternType.setAbstract(true);
        return patternType;
    }

    protected PatternType fillCommonPatternType(PatternType patternType) {
        patternType.setLocalId(helper.getLocalId(method));
        patternType.setCaption(helper.getFormattedCaption(method));
        if (method.getAnnotation(Processor.class) != null) {
            patternType.setExtends(helper.getUrl(module) + helper.getGlobalRefId(module.getModuleName()));
            String returnType = method.getReturnType().toString();

            if (method.getAnnotation(Paged.class) != null) {
                returnType = helper.getPagedReturnType(method);
            }

            patternType.setReturnType(returnType);
        } else if (method.getAnnotation(Transformer.class) != null) {
            patternType.setExtends(helper.getUrl(module) + AbstractTransformerBuilder.ABSTRACT_TRANSFORMER_LOCAL_ID);
            patternType.setDescription(helper.formatDescription(method.getJavaDocSummary()));
        }

        Category category = module.getAnnotation(Category.class);
        if (category != null && StringUtils.isNotBlank(category.name())) {
            patternType.setCategory(category.name());
        }

        patternType.setIcon(getIcon());
        patternType.setImage(getImage());
        return patternType;
    }

    protected String getImage() {
        if (method.getAnnotation(Transformer.class) != null) {
            return helper.getTransformerImage(module);
        } else if (isContainer(method)){
            return helper.getContainerImage(module);
        }else if (isContainerList(method)){
            return helper.getFlowImage(module);
        }else {
            return helper.getConnectorImage(module);
        }
    }

    protected String getIcon() {
        if (method.getAnnotation(Transformer.class) != null) {
            return helper.getTransformerIcon(module);
        } else if (isContainer(method)){
            return helper.getContainerIcon(module);
        }else if (isContainerList(method)){
            return helper.getFlowIcon(module);
        }else {
            return helper.getConnectorIcon(module);
        }
    }

    /**
     * Used when describing a processor, if the current module has connection management or if it has an strategy
     * with @ConnectionManagement that also has been annotated with @OverrideAtProcessors, then the processor must have
     * the parameters of @Connect as attributes as well.
     *
     * @param groupsByName
     * @param attributeCategoriesByName
     */
    @Override
    protected void processConnectionAttributes(Map<String, Group> groupsByName, Map<String, AttributeCategory> attributeCategoriesByName) {
        ConnectionManagementCapability connectionManagementCapability = null;
        if (module.manager().connectionManagementOverride().isPresent()){
            connectionManagementCapability = module.manager().connectionManagementOverride().get();
        } else if(module instanceof ManagedConnectionModule) {
            connectionManagementCapability = (ConnectionManagementCapability) module;
        }

        if (connectionManagementCapability != null ) {
            Group connectionAttributesGroup = new Group();
            connectionAttributesGroup.setCaption(helper.formatCaption(ADVANCED_CONNECTION_GROUP_NAME));
            connectionAttributesGroup.setId(StringUtils.uncapitalize(ADVANCED_CONNECTION_GROUP_NAME));

            groupsByName.put(ADVANCED_CONNECTION_GROUP_NAME, connectionAttributesGroup);

            List<AttributeType> connectionAttributes = getConnectionAttributes(connectionManagementCapability);
            connectionAttributesGroup.getRegexpOrEncodingOrModeSwitch().addAll(helper.createJAXBElements(connectionAttributes));

            AttributeCategory connectionAttributeCategory = new AttributeCategory();
            connectionAttributeCategory.setCaption(helper.formatCaption(MuleStudioEditorXmlGenerator.ADVANCED_ATTRIBUTE_CATEGORY_CAPTION));
            connectionAttributeCategory.setDescription(helper.formatDescription(MuleStudioEditorXmlGenerator.ADVANCED_ATTRIBUTE_CATEGORY_CAPTION));
            attributeCategoriesByName.put(MuleStudioEditorXmlGenerator.ADVANCED_ATTRIBUTE_CATEGORY_CAPTION, connectionAttributeCategory);
            connectionAttributeCategory.getGroup().add(connectionAttributesGroup);
        }
    }
}
